@@ -402,6 +402,14 @@ class LabeledView(LabelingMixin, View):
                                list(other.label_list(0)))
         return LabeledView(concat_dense, [newlabels] + self.label_lists()[1:])
 
+    def with_zeros_removed(self):
+        '''
+        Make a new LabeledView of a DictTensor with all the non-zero
+        items in this tensor.
+        '''
+        return make_sparse_labeled_tensor(ndim=self.ndim, initial=(
+                (k, v) for k, v in self.iteritems() if v))
+    
     def k_means(self, k=20, **kw):
         means, clusters = self.tensor.k_means(k, **kw)
         labeled_clusters = [self.label(0, index) for index in cluster]
