@@ -769,6 +769,11 @@ class DictTensor(Tensor):
     def purge(self):
         '''
         Removes any values that are specified as the default value.
+
+        Note: this method can't remove any empty rows or columns,
+        since that would require changing indices. You may be
+        interested in
+        :meth:`csc.divisi.labeled_view.LabeledView.with_zeros_removed`.
         '''
         self._recursive_purge(self._data, self.ndim - 1)
 
